summaryrefslogtreecommitdiffstats
path: root/kmail/kmfolder.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmail/kmfolder.h')
-rw-r--r--kmail/kmfolder.h35
1 files changed, 18 insertions, 17 deletions
diff --git a/kmail/kmfolder.h b/kmail/kmfolder.h
index 77979b98..83a4a7a2 100644
--- a/kmail/kmfolder.h
+++ b/kmail/kmfolder.h
@@ -60,7 +60,7 @@ typedef TQValueList<TQ_UINT32> SerNumList;
*
* @section Accounts
* The accounts (of KMail) that are fed into the folder are
- * represented as the children of the folder. They are only stored here
+ * represented as the tqchildren of the folder. They are only stored here
* during runtime to have a reference for which accounts point to a
* specific folder.
*/
@@ -68,14 +68,15 @@ typedef TQValueList<TQ_UINT32> SerNumList;
class KMFolder: public KMFolderNode
{
Q_OBJECT
+ TQ_OBJECT
friend class ::KMFolderJob;
public:
/**
* Constructs a new Folder object.
* @param parent The directory in the folder storage hierarchy under which
* the folder's storage will be found or created.
* @param name If name of the folder. In case there is no parent directory, because
* the folder is free-standing (/var/spool/mail/foo), this is used for the full path to
* the folder's storage location.
* @param aFolderType The type of folder to create.
@@ -86,7 +87,7 @@ public:
* the global MsgDict for lookup.
* @return A new folder instance.
*/
- KMFolder( KMFolderDir* parent, const TQString& name,
+ KMFolder( KMFolderDir* tqparent, const TQString& name,
KMFolderType aFolderType, bool withIndex = true,
bool exportedSernums = true );
~KMFolder();
@@ -168,10 +169,10 @@ public:
/** Specify, that the folder can't contain mails. */
void setNoContent(bool aNoContent);
- /** Returns, if the folder can't have children */
+ /** Returns, if the folder can't have tqchildren */
bool noChildren() const;
- /** Specify, that the folder can't have children */
+ /** Specify, that the folder can't have tqchildren */
void setNoChildren(bool aNoChildren);
/** Read message at given index. Indexing starts at zero */
@@ -196,7 +197,7 @@ public:
* for each derived KMFolder).
*/
FolderJob* createJob( KMMessage *msg, FolderJob::JobType jt = FolderJob::tGetMessage,
- KMFolder *folder = 0, TQString partSpecifier = TQString::null,
+ KMFolder *folder = 0, TQString partSpecifier = TQString(),
const AttachmentStrategy *as = 0 ) const;
FolderJob* createJob( TQPtrList<KMMessage>& msgList, const TQString& sets,
FolderJob::JobType jt = FolderJob::tGetMessage,
@@ -259,8 +260,8 @@ public:
int moveMsg(TQPtrList<KMMessage>, int* index_return = 0);
/** Returns the index of the given message or -1 if not found. */
- int find(const KMMsgBase* msg) const;
- int find( const KMMessage * msg ) const;
+ int tqfind(const KMMsgBase* msg) const;
+ int tqfind( const KMMessage * msg ) const;
/** Number of messages in this folder. */
int count(bool cache = false) const;
@@ -272,10 +273,10 @@ public:
contained by this folder */
int countUnreadRecursive();
/** Called by KMMsgBase::seStatus when status of a message has changed
required to keep the number unread messages variable current. */
- void msgStatusChanged( const KMMsgStatus oldStatus,
- const KMMsgStatus newStatus,
+ void msgStatusChanged( const KMMsgtqStatus oldtqStatus,
+ const KMMsgtqStatus newtqStatus,
int idx);
/** Open folder for access.
@@ -337,7 +338,7 @@ public:
/** Change the dirty flag. */
void setDirty(bool f);
- /** Returns true if the folder tqcontains deleted messages */
+ /** Returns true if the folder contains deleted messages */
bool needsCompacting() const;
void setNeedsCompacting(bool f);
@@ -489,10 +490,10 @@ public:
int writeIndex( bool createEmptyIndex = false );
/** Set the status of the message at index @p idx to @p status. */
- void seStatus(int idx, KMMsgStatus status, bool toggle=false);
+ void setqStatus(int idx, KMMsgtqStatus status, bool toggle=false);
/** Set the status of the message(s) in the TQValueList @p ids to @p status. */
- void seStatus(TQValueList<int>& ids, KMMsgStatus status, bool toggle=false);
+ void setqStatus(TQValueList<int>& ids, KMMsgtqStatus status, bool toggle=false);
/** Icon related methods */
bool useCustomIcons() const { return mUseCustomIcons; }
@@ -541,7 +542,7 @@ public:
/**
* Returns true if the name is valid for a child of this folder.
- * If the name tqcontains invalid characters then false is returned and message will contain
+ * If the name contains invalid characters then false is returned and message will contain
* an explanation that can be presented to the user.
*/
bool isValidName( const TQString &folderName, TQString &message );
@@ -639,7 +640,7 @@ private:
bool mExportsSernums :1;
bool mMoveInProgress :1;
- /** nationalized label or TQString::null (then name() should be used) */
+ /** nationalized label or TQString() (then name() should be used) */
TQString mLabel;
TQString mSystemLabel;
@@ -68,14 +68,15 @@ typedef TQValueList<TQ_UINT32> SerNumList;
/**
* Constructs a new Folder object.
- * @param parent The directory in the folder storage hierarchy under which
+ * @param tqparent The directory in the folder storage hierarchy under which
* the folder's storage will be found or created.
@@ -68,14 +68,15 @@ typedef TQValueList<TQ_UINT32> SerNumList;
* the folder's storage will be found or created.
- * @param name If name of the folder. In case there is no parent directory, because
+ * @param name If name of the folder. In case there is no tqparent directory, because
* the folder is free-standing (/var/spool/mail/foo), this is used for the full path to
* the folder's storage location.
@@ -272,10 +273,10 @@ public:
contained by this folder */
int countUnreadRecursive();
- /** Called by KMMsgBase::seStatus when status of a message has changed
+ /** Called by KMMsgBase::setqStatus when status of a message has changed
required to keep the number unread messages variable current. */